The `cub` folder is a git submodule for the CUB project.
Including the CUB headers as a submodule enables not only building the `cupy.cuda.cub` module,
but also easier maintenance.
For further information on CUB, see the [CUB Project Website](http://nvlabs.github.com/cub).
